# Welcome to django-cloud-storages

django-cloud-storages is a package developed for django to work with cloud storages to store/upload media files.

This package extends the [django Storage class](https://docs.djangoproject.com/en/4.2/ref/files/storage/#django.core.files.storage.Storage) to provide file storage in cloud.

At the moment this package support the following cloud storage services -

* AppWrite
* DropBox

### **Installation**

---

Use pip to install from PyPI:

   `pip install django-cloud-storages`

It will install all the cloud storage backends (available in this package), you can choose any of the storage backend as per your requirement.

### **Documentation**

The documentation for the package *django-cloud-storage* is available at [https://django-cloud-storages.readthedocs.io](https://django-cloud-storages.readthedocs.io/).

### **Contributing**

---

To contribute to django-cloud-storages [create a fork](https://github.com/Samiddha99/django-cloud-storages) on GitHub. Clone your fork, make some changes, and submit a pull request.

### **Issues**

---

Use the GitHub [issue tracker](https://github.com/Samiddha99/django-cloud-storages/issues) for django-cloud-storages to submit bugs, issues, and feature requests.
